/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.twa.ui.fields;

import java.io.File;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.IWorkspaceRoot;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IPath;
import org.eclipse.swt.widgets.Composite;

import benten.core.io.ResourceFile;
import benten.twa.TwaPlugin;
import benten.twa.ui.dialogs.AbstractResourceSelectionDialog;
import benten.twa.ui.dialogs.ResourceFileSelectionDialog;

/**
 * プロジェクトのファイルを選択するためのテキスト・フィールドです。
 */
public class ResourceFileTextField extends AbstractBrowseTextField {

	public ResourceFileTextField(Composite parent, String labelText, String... extensions) {
		super(parent, labelText, extensions);
	}

	@Override
	protected void openDialog() {
		final AbstractResourceSelectionDialog dialog = createDialog();
		final String s = text.getText();
		if (s.length() > 0) {
			final IResource res = getResource(s);
			if (res != null && res.exists()) {
				dialog.setInitialSelections(new Object[] { res });
			}
		}
		dialog.open();
		final Object[] result = dialog.getResult();
		if (result != null && result.length > 0) {
			final IResource resource = (IResource) result[0];
			setResource(resource);
		}
	}

	protected AbstractResourceSelectionDialog createDialog() {
		final IProject[] projects = ResourcesPlugin.getWorkspace().getRoot().getProjects();
		final ResourceFileSelectionDialog dialog = new ResourceFileSelectionDialog(parent.getShell(), projects);
		dialog.setExtensions(extensions);
		return dialog;
	}

	@Override
	public void setText(String path) {
		try {
			if (path != null && !path.equals("")) {
				text.setText(path.replaceFirst("^/", ""));
			} else {
				final String prevDir = previousInputMap.get(labelText);
				if (prevDir != null) {
					text.setText(prevDir == null ? "" : prevDir);
				}
			}
		} catch (final Exception e) {
			TwaPlugin.log(e);
		}
	}

	@Override
	public File getFile() {
		final IResource resource = getResource();
		if (resource != null) {
			final IPath location = resource.getLocation();
			if (location != null) {
				return new File(location.toOSString());
			}
		}
		return null;
	}
	public void setResource(IResource resource) {
		text.setText(ResourceFile.relativePath(resource));
	}

	public IResource getResource() {
		return getResource(getText());
	}

	protected IResource getResource(String relativePath) {
		final IWorkspaceRoot workspaceRoot = ResourcesPlugin.getWorkspace().getRoot();
		final String[] segments = relativePath.replace("\\", "/").replaceFirst("^/", "").split("/");
		if (segments.length == 1) {
			return null;
		}
		final String projectName = segments[0];
		final IProject project = workspaceRoot.getProject(projectName);
		final String path = relativePath.replaceFirst(projectName + "/", "");
		return project.getFile(path);
	}
}
