/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.twa.ui.fields;

import org.eclipse.jface.fieldassist.ControlDecoration;
import org.eclipse.jface.fieldassist.FieldDecoration;
import org.eclipse.jface.fieldassist.FieldDecorationRegistry;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Layout;
import org.eclipse.swt.widgets.Text;

import benten.ui.views.UiToolkit;

/**
 * テキスト・フィールドです。
 */
public class TextField {

	protected final UiToolkit toolkit = new UiToolkit();
	protected final Composite parent;
	protected final String labelText;
	protected final Label label;
	protected final Text text;

	public TextField(Composite parent, String labelText) {
		Layout layout = parent.getLayout();
		if (layout instanceof GridLayout) {
			GridLayout gd = (GridLayout) layout;
			gd.horizontalSpacing = 10;
		}
		this.parent = parent;
		this.labelText = labelText;
		label = toolkit.createLabel(parent, labelText + ":");
		GridData gd = new GridData(GridData.FILL_HORIZONTAL);
		gd.widthHint = 450;
		text = new Text(parent, SWT.SINGLE | SWT.BORDER);
		text.setLayoutData(gd);
	}

	public void addModifyListener(ModifyListener listener) {
		text.addModifyListener(listener);
	}

	public void setText(String value) {
		text.setText(value == null ? "" : value);
	}

	public String getText() {
		return text.getText() == null ? "" : text.getText().trim();
	}

	public String getLabelText() {
		return labelText;
	}

	public void setInfoDecoration(String descriptionText) {
		ControlDecoration decoration = new ControlDecoration(text, SWT.RIGHT | SWT.BOTTOM);
		decoration.setDescriptionText(descriptionText);
		FieldDecoration fieldDecoration = FieldDecorationRegistry.getDefault().getFieldDecoration(
				FieldDecorationRegistry.DEC_INFORMATION);
		decoration.setImage(fieldDecoration.getImage());
		decoration.show();
	}
}
